@@ -1,25 +1,41 @@
 from abc import ABC, abstractmethod
-from typing import Callable, Union
+from typing import Callable, Union, TypeVar, Dict, Any, Tuple, Optional
 from functools import wraps
 
 
+QueryT = TypeVar("QueryT")
+
+
 class Specification(ABC):
     @abstractmethod
-    def apply(self, query):
+    def apply(self, query: QueryT) -> QueryT:
         raise NotImplementedError("Specification must specify apply()")
 
-    def __call__(self, query):
+    def __call__(self, query: QueryT) -> QueryT:
         return self.apply(query)
 
 
+def filter_parameter_parser(
+    field: str,
+    value: Any,
+    filter_mappings: Dict[str, Callable],
+) -> Tuple[Optional[str], Optional[Any]]:
+    for filter_ending, filter_func in filter_mappings.items():
+        if field.endswith(filter_ending):
+            return filter_ending, filter_func(field.replace(filter_ending, ""), value)
+
+    return None, None
+
+
 def specification(func: Callable):
     def create_specification(*args, **kwargs):
 
         @wraps(func)
-        def created_specification(query):
+        def created_specification(query: QueryT) -> QueryT:
             return func(*args, **kwargs, query=query)
 
         return created_specification
+
     return create_specification
 
 
@@ -38,4 +54,5 @@ __all__ = [
     'Specification',
     'specification',
     'SpecificationType',
+    'filter_parameter_parser',
 ]
